@@ -52,7 +52,7 @@ class DataConverter:
                 converted_dict[field.name]=None
         return cls(**converted_dict)
 
-    def get_instances_from_arr_of_dicts(self,arr_of_dicts : list[dict],cls):
+    def get_instances_from_arr_of_dicts(self,arr_of_dicts,cls):
         return [self.get_instance_from_dict(d,cls) for d in arr_of_dicts]
     # Convert a dataclass instance to a dict in the form {field_name_1 : field_val_1, ...}.
     # No type conversions are currently performed, but they can be added as needed.
